@@ -3,4 +3,6 @@
 # SPDX-License-Identifier: MPL-2.0
 # flake8: noqa
 """This module defines the public interface of the RAMQP package."""
-from .amqpsystem import AMQPSystem
+from .amqp import AMQPSystem
+from .amqp import PublishMixin
+from .amqp import Router
