@@ -83,6 +83,23 @@ class AbstractRouter:
                 pass
             ```
 
+        Note that, unlike the MOAMQPSystem where exclusive message handling is the
+        default, semantically identical messages may be handled concurrently due to the
+        parallelism provided by the `prefetch_count` setting. This can lead to race
+        conditions in the application if multiple callbacks read and write state in an
+        intertwined fashion. Unfortunately, because the semantics of the payload is
+        unknown, exclusivity cannot automatically be provided. Instead, it is
+        recommended to wrap all sensitive functions manually::
+
+            @router.register("my.routing.key")
+            async def callback1(message: IncomingMessage, **kwargs: Any):
+                payload = parse_obj_as(Payload, message)
+                await handler(payload, **kwargs)
+
+            @handle_exclusively(key=lambda payload, **kwargs: (payload.id, payload.foo))
+            async def handler(payload: Payload, **kwargs):
+                pass
+
         Args:
             routing_key: The routing key to bind messages for.
 
@@ -245,7 +262,7 @@ class AbstractAMQPSystem(AbstractAsyncContextManager, Generic[TRouter]):
 
         logger.info("Creating AMQP channel")
         self._channel = cast(AbstractRobustChannel, await self._connection.channel())
-        await self._channel.set_qos(prefetch_count=10)
+        await self._channel.set_qos(prefetch_count=settings.prefetch_count)
         _setup_channel_metrics(self._channel)
 
         logger.info("Attaching AMQP exchange to channel", exchange=settings.exchange)
@@ -358,7 +375,11 @@ class AbstractAMQPSystem(AbstractAsyncContextManager, Generic[TRouter]):
         assert message.routing_key is not None
         routing_key = message.routing_key
         function_name = function_to_name(callback)
-        log = logger.bind(function=function_name, routing_key=routing_key)
+        log = logger.bind(
+            function=function_name,
+            routing_key=routing_key,
+            message_id=message.message_id,
+        )
 
         log.debug("Received message")
         try:
